import QtQuick 1.1
import com.nokia.meego 1.1
import com.nokia.extras 1.1
import "./controls"

Page {
	id: mainPage
	tools: mainTools
	orientationLock: PageOrientation.LockPortrait
	//anchors.margins: rootWindow.pageMargin
	property string serv_dt_msec: "0"

	function openFile(file) {
		var component = Qt.createComponent(file)
		if (component.status == Component.Ready)
			pageStack.push(component);
		else
			console.log("Error loading component:", component.errorString());
	}
	function set_dt(serv_dt_str,sys_dt_str) {
		textServTime.text=serv_dt_str;
		textLocalTime.text=sys_dt_str;
		servBox.state= "StateOk";

		if (!buttSycnServ.enabled) {
			buttSycnServ.enabled=true;
		}
	}

	function show_err(err){
		textServTime.text=err;
		servBox.state= "StateErr";

	}

	function sync_err(){
		syncBox.state= "StateErr";
	}

	function sync_ok(){
		syncBox.state= "StateOk";
	}

	PageHeader {
		id: headerP
		text: "Synchronization Time"
	}

	Connections {
		target: objNtpDate
		onSigSecOverStr: mainPage.set_dt(serv_dt_str,sys_dt_str)
		onSigError: mainPage.show_err(err)
		onSigSyncErr: mainPage.sync_err()
		onSigSyncOk: mainPage.sync_ok()
	}


	Flickable {

		id: flickable
		anchors.top: headerP.bottom
		anchors.left: parent.left
		anchors.right: parent.right
		anchors.bottom: parent.bottom
		//anchors.fill: parent
		//contentHeight: itemPage.childrenRect.height+50
		flickableDirection: Flickable.VerticalFlick

		Column
		{

			anchors.top: parent.top
			anchors.topMargin: 30
			anchors.left: parent.left
			anchors.leftMargin: 30
			anchors.right: parent.right
			anchors.rightMargin: 30
			spacing : 16

			Row{
				id: servRow
				anchors.left: parent.left
				anchors.right: parent.right
				spacing: 10

				Button {
					id: buttShowServ;
					//icon-m-invitation-accept.png icon-m-invitation-declined.png
					//anchors.left: servBox.right
					//anchors.right: parent.right
					width: parent.width-servBox.width-10
					text: "Show server date and time"
					onClicked: {
						buttSycnServ.enabled=false;
						servBox.state= "StateUpd";
						syncBox.state= "StateNone";
						textServTime.text="Try connect to server..";
						objNtpDate.sltGenServDt();
					}
				}
				InfoBox{
					id: servBox
					state: "StateNone"
					height: buttShowServ.height
					width: buttShowServ.height
				}
			}
			Text {
				id: labelServTime

				anchors.horizontalCenter: servRow.horizontalCenter
				font.pointSize: 24
				font.bold: true
				text: "Server Time:"
			}
			Text {
				id: textServTime

				anchors.horizontalCenter: servRow.horizontalCenter
				text: "--:--:-- --.--.----"
				font.pointSize: 24
			}

			Text {
				id: labelLocalTime

				anchors.horizontalCenter: servRow.horizontalCenter
				font.pointSize: 24
				font.bold: true
				text: "Local Time:"
			}
			Text {
				id: textLocalTime

				anchors.horizontalCenter: servRow.horizontalCenter
				text: "--:--:-- --.--.----"
				font.pointSize: 24
			}
			Row{
				id: syncRow
				anchors.left: parent.left
				anchors.right: parent.right
				spacing: 10

				Button {
					id: buttSycnServ;

//					anchors.left: parent.left
//					anchors.right: parent.right
					width: parent.width-syncBox.width-10
					enabled: false
					text: "Sync date and time"
					onClicked: {
						syncBox.state= "StateUpd";
						objNtpDate.sltSynctSysDt();
					}
				}
				InfoBox{
					id: syncBox
					state: "StateNone"
					height: buttShowServ.height
					width: buttShowServ.height
				}
			}


		}
		Component.onCompleted: {
			objParams.sltAddParam("TIME_HOST","utcnist.colorado.edu");
			objParams.sltAddParam("TIME_PORT",37);
			objParams.sltAddParam("HOURS_DIFF",0);
			objParams.sltAddParam("MIN_DIFF",0);
			objParams.sltAddParam("USE_SYS_UTC_DIFF",false);
			objParams.sltAddParam("TYPE_TIME_CHANGE",1);
			objParams.sltLoadAll();
			//console.log("Image changed!")
		}
	}

	ScrollDecorator {
		flickableItem: flickable
	}

	ToolBarLayout {
		id: mainTools
		ToolIcon {
			iconId: "icon-m-toolbar-settings";
			onClicked: { mainPage.openFile("SettingsPage.qml"); }
		}

//		ToolIcon {
//			iconId: "toolbar-view-menu";
//			onClicked: (mainMenu.status == DialogStatus.Closed)
//					   ? mainMenu.open()
//					   : mainMenu.close()
//		}

		ToolIcon{
			iconId: "icon-m-toolbar-favorite-unmark-dimmed-white"
			onClicked: { mainPage.openFile("AboutPage.qml"); }
		}
		ToolIcon{
			iconId: "icon-m-toolbar-close"
			onClicked: Qt.quit()
		}
	}


//	Menu {
//		id: mainMenu
//		visualParent: pageStack
//		content: MenuLayout {
//			MenuItem {
//				text: "Settings.."
//				onClicked: {
//					mainPage.openFile("SettingsPage.qml");
//				}
//			}
//			MenuItem {
//				text: "About.."
//				onClicked: {
//					mainPage.openFile("AboutPage.qml");
//				}
//			}
//			MenuItem {
//				text: "Exit"
//				onClicked:  Qt.quit()
//			}
//		}
//	}

}     
