import QtQuick 1.1
import com.nokia.meego 1.1
import "./controls"

Page {
	id: settingsPage
	tools: settingsTools
	orientationLock: PageOrientation.LockPortrait
	//anchors.margins: rootWindow.pageMargin
	property int currTypeSys: 1
	PageHeader {
		id: headerP
		text: "Settings"
	}

	ToolBarLayout {
		id: settingsTools

		ToolButtonRow {
			ToolButton {
				text: "Apply";
				onClicked: { save(); }
			}
			ToolButton {
				text: "Cancel";
				onClicked: { pageStack.pop(); }
			}
		}
	}

	Flickable {

		id: flickable
		anchors.top: headerP.bottom
		anchors.left: parent.left
		anchors.right: parent.right
		anchors.bottom: parent.bottom
		//anchors.fill: parent
		//contentHeight: itemPage.childrenRect.height+50
		flickableDirection: Flickable.VerticalFlick

		Column
		{
			anchors.top: parent.top
			anchors.topMargin: 10
			anchors.left: parent.left
			anchors.leftMargin: 30
			anchors.right: parent.right
			anchors.rightMargin: 30
			spacing : 5 //16

			Label {
				id: labelTypeSys
				text: "Type update system time:"
				anchors.left: parent.left
			}

			ButtonColumn {
				id: systypeBC
				anchors.left: parent.left
				anchors.right: parent.right

				Button {
					id: openmodeButt
					text: "OpenMode kernel"
					onClicked: {
						settingsPage.currTypeSys=1;
					}

				}
				Button {
					id: aegisButt
					text: "Aegis-hack + opensudo"
					onClicked: {
						settingsPage.currTypeSys=2;
					}
				}

			}

			Label {
				id: labelPassw
				text: "Root password:"
				anchors.left: parent.left
			}

			TextField {
				id: textFieldPassw
				echoMode: TextInput.Password

				//placeholderText: "TextField"

				anchors.left: parent.left
				anchors.right: parent.right
			}

			Label {
				id: labelServIP
				text: "Time Server IP Address:"
				anchors.left: parent.left
			}

			TextField {
				id: textFieldServIP

				//placeholderText: "TextField"

				anchors.left: parent.left
				anchors.right: parent.right
			}

			Label {
				id: labelServPort
				anchors.left: parent.left

				text: "Time Server Port:"
			}
			TextField {
				id: textFieldServPort
				//errorHighlight: !acceptableInput
				validator: IntValidator{bottom: 1; top: 999999;}

				anchors.left: parent.left
				anchors.right: parent.right
			}

			Label {
				id: labelAddHours
				anchors.left: parent.left
				text: "Add hours to time of server:"
			}

			UpDownEditor
			{
				id: addHoursUDE
				anchors.left: parent.left
				anchors.right: parent.right

				//anchors.centerIn: parent
				minValue: -12
				maxValue: 12
				currValue: 0

			}

			Label {
				id: labelAddMins
				anchors.left: parent.left
				text: "Add mins to time of server:"
			}

			UpDownEditor
			{
				id: addMinsUDE
				anchors.left: parent.left
				anchors.right: parent.right

				//anchors.centerIn: parent
				minValue: -59
				maxValue: 59
				currValue: 0

			}
			CheckBox {
				id: useUtcCB
				anchors.left: parent.left

				text: "Used system UTC differents"
				checked: true
			}
		}



	}
	
	ScrollDecorator {
		flickableItem: flickable
	}

	function save() {
		objParams.sltSetParam("PSWD",textFieldPassw.text);
		objParams.sltSetParam("TIME_HOST",textFieldServIP.text);
		objParams.sltSetParam("TIME_PORT",textFieldServPort.text);
		objParams.sltSetParam("HOURS_DIFF",addHoursUDE.currValue);
		objParams.sltSetParam("MIN_DIFF",addMinsUDE.currValue);
		objParams.sltSetParam("USE_SYS_UTC_DIFF",useUtcCB.checked);

		objParams.sltSetParam("TYPE_TIME_CHANGE",settingsPage.currTypeSys);


		objParams.sltSaveAll();
		//objParams.sltDebugParams();
		pageStack.pop();
	}
	
	Component.onCompleted: {
		textFieldPassw.text = objParams.getParam("PSWD");
		textFieldServIP.text = objParams.getParam("TIME_HOST");
		textFieldServPort.text = objParams.getParam("TIME_PORT");
		addHoursUDE.currValue = objParams.getParam("HOURS_DIFF");
		addMinsUDE.currValue = objParams.getParam("MIN_DIFF");
		useUtcCB.checked = objParams.getParam("USE_SYS_UTC_DIFF");
		settingsPage.currTypeSys = objParams.getParam("TYPE_TIME_CHANGE");

		if (settingsPage.currTypeSys==2){
			aegisButt.checked = true;
		}
		else {
			openmodeButt.checked = true;
		}
		//objParams.sltDebugParams();
	}
}     
